@@ -1,4 +1,4 @@
-package App::MonM; # $Id: MonM.pm 136 2022-09-09 15:37:03Z abalama $
+package App::MonM; # $Id: MonM.pm 151 2022-09-16 07:45:23Z abalama $
 use warnings;
 use strict;
 use utf8;
@@ -11,7 +11,7 @@ App::MonM - Simple monitoring tool
 
 =head1 VERSION
 
-Version 1.08
+Version 1.09
 
 =head1 SYNOPSIS
 
@@ -118,7 +118,6 @@ Format for time can be in any of the following forms:
     1d   -- in 1 day
     3M   -- in 3 months
     2y   -- in 2 years
-    3m   -- 3 minutes ago(!)
 
 Default: 1d (1 day)
 
@@ -229,7 +228,7 @@ See L<App::MonM::Checkit/CONFIGURATION DIRECTIVES>
 
 =head2 CRONTAB
 
-To automatically launch the program, we recommend using standard scheduling tools, such as crontab
+To automatically launch the program, you can using standard scheduling tools, such as crontab
 
     * * * * * monm checkit >/dev/null 2>>/var/log/monm-error.log
 
@@ -309,11 +308,10 @@ See C<LICENSE> file and L<https://dev.perl.org/licenses/>
 =cut
 
 use vars qw/ $VERSION /;
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 use feature qw/ say /;
 
-use Carp;
 use Text::SimpleTable;
 use File::Spec;
 use File::stat qw//;
@@ -365,7 +363,6 @@ eval { require App::MonM::Notifier };
 my $NOTIFIER_LOADED = 1 unless $@;
 $NOTIFIER_LOADED = 0 if $NOTIFIER_LOADED && (App::MonM::Notifier->VERSION * 1) < 1.04;
 
-
 sub again {
     my $self = shift;
        $self->SUPER::again(); # CTK::App again first!!
@@ -1108,11 +1105,30 @@ sub notify {
             to      => $sendto,
             subject => $subject,
             message => $report->as_string,
+            before => sub {
+                my $this = shift; # App::MonM::QNotifier object (this)
+                my $message = shift; # App::MonM::Message object
+
+                # Check internal errors
+                if ($this->error) {
+                    nope($this->error);
+                    $self->log_error($this->error);
+                }
+
+                return 1;
+            },
             after => sub {
                 my $this = shift; # App::MonM::QNotifier object (this)
                 my $message = shift; # App::MonM::Message object
                 my $sent = shift; # Status of sending
 
+                # Check internal errors
+                if ($this->error) {
+                    nope($this->error);
+                    $self->log_error($this->error);
+                }
+
+                # Check sending status
                 if ($sent) {
                     my $msg = $this->channel->error
                         ? sprintf("Message was not sent to %s: %s", $message->recipient, $this->channel->error)
